## Examples

Please note that this folder contains only example dashboards that are still **in development**.

### Vizro examples gallery

To view a comprehensive list of available demos, please visit our [examples gallery](http://vizro.mckinsey.com/).
There, you can explore a wide range of dashboards and applications created with Vizro.

<a href="http://vizro.mckinsey.com/">
<img src="https://raw.githubusercontent.com/mckinsey/vizro/main/.github/images/vizro_examples_gallery.png" width="600"/>
</a>

### Huggingface collection

For a curated list of example dashboards, check out our [dashboard collection on Huggingface](https://huggingface.co/collections/vizro/vizro-official-gallery-66697d414646eeac61eae6de).

<a href="https://huggingface.co/collections/vizro/vizro-official-gallery-66697d414646eeac61eae6de">
<img src="https://raw.githubusercontent.com/mckinsey/vizro/main/.github/images/huggingface_collection.png" width="600"/>
</a>
